@@ -24,47 +24,52 @@
 #############################################################################
 
 
-#' Jordan networks are partially recurrent networks 
-#' and similar to Elman networks (see \code{\link{elman}}). Partially recurrent networks 
-#' are useful when working with time series data. I.e., when the output of the 
-#' network not only should depend on the current pattern, but also on the patterns
-#' presented before.
+#' Jordan networks are partially recurrent networks and similar to Elman
+#' networks (see \code{\link{elman}}). Partially recurrent networks are useful
+#' when working with time series data. I.e., when the output of the network not
+#' only should depend on the current pattern, but also on the patterns presented
+#' before.
 #' 
-#' Learning on Jordan networks:
-#' Backpropagation algorithms for feed-forward networks can be adapted for their use with 
-#' this type of networks. In SNNS, there exist adapted versions of several backpropagation-type
-#' algorithms for Jordan and Elman networks.  
+#' Learning on Jordan networks: Backpropagation algorithms for feed-forward
+#' networks can be adapted for their use with this type of networks. In SNNS,
+#' there exist adapted versions of several backpropagation-type algorithms for
+#' Jordan and Elman networks.
 #' 
-#' Network architecture: A Jordan network can be seen as a feed-forward network with additional
-#' context units in the input layer. These context units take input from themselves (direct feedback), and from 
-#' the output units. The context units save the current state of the net. In a Jordan net, the number of context 
-#' units and output units has to be the same.
+#' Network architecture: A Jordan network can be seen as a feed-forward network
+#' with additional context units in the input layer. These context units take
+#' input from themselves (direct feedback), and from the output units. The
+#' context units save the current state of the net. In a Jordan net, the number
+#' of context units and output units has to be the same.
 #' 
-#' Initialization of Jordan and Elman nets should be done with the default init function \code{JE_Weights}, which 
-#' has five parameters. The first two parameters define an interval from which the forward connections are randomly
-#' chosen. The third parameter gives the self-excitation weights of the context units. The fourth parameter gives the
-#' weights of context units between them, and the fifth parameter gives the initial activation of context units.
+#' Initialization of Jordan and Elman nets should be done with the default init
+#' function \code{JE_Weights}, which has five parameters. The first two
+#' parameters define an interval from which the forward connections are randomly
+#' chosen. The third parameter gives the self-excitation weights of the context
+#' units. The fourth parameter gives the weights of context units between them,
+#' and the fifth parameter gives the initial activation of context units.
 #' 
-#' Learning functions are \code{JE_BP}, \code{JE_BP_Momentum}, \code{JE_Quickprop}, and \code{JE_Rprop}, which are all
-#' adapted versions of their standard-procedure counterparts.  
-#' Update functions that can be used are \code{JE_Order} and \code{JE_Special}.
+#' Learning functions are \code{JE_BP}, \code{JE_BP_Momentum},
+#' \code{JE_Quickprop}, and \code{JE_Rprop}, which are all adapted versions of
+#' their standard-procedure counterparts.  Update functions that can be used are
+#' \code{JE_Order} and \code{JE_Special}.
 #' 
-#' A detailed description of the theory and the parameters is available, as always, from the SNNS 
-#' documentation and the other referenced literature.
+#' A detailed description of the theory and the parameters is available, as
+#' always, from the SNNS documentation and the other referenced literature.
 #' 
 #' @title Create and train a Jordan network
-#' @references 
-#' Jordan, M. I. (1986), 'Serial Order: A Parallel, Distributed Processing Approach', Advances in Connectionist Theory Speech 121(ICS-8604), 471-495.
+#' @references Jordan, M. I. (1986), 'Serial Order: A Parallel, Distributed
+#' Processing Approach', Advances in Connectionist Theory Speech 121(ICS-8604),
+#' 471-495.
 #' 
-#' Zell, A. et al. (1998), 'SNNS Stuttgart Neural Network Simulator User Manual, Version 4.2', IPVR, University of Stuttgart and WSI, University of Tübingen. 
+#' Zell, A. et al. (1998), 'SNNS Stuttgart Neural Network Simulator User Manual,
+#' Version 4.2', IPVR, University of Stuttgart and WSI, University of Tübingen.
 #' \url{http://www.ra.cs.uni-tuebingen.de/SNNS/}
 #' 
 #' Zell, A. (1994), Simulation Neuronaler Netze, Addison-Wesley. (in German)
 #' @export
 jordan <- function(x, ...) UseMethod("jordan")
 
-#' Create and train a jordan network. 
-#' 
+
 #' @param x a matrix with training inputs for the network
 #' @param y the corresponding targets values
 #' @param size number of units in the hidden layer(s)
@@ -121,7 +126,7 @@ jordan.default <- function(x, y, size=c(5), maxit=100,
     initFunc="JE_Weights", initFuncParams=c(1.0,  -1.0,  0.3,  1.0,  0.5), 
     learnFunc="JE_BP", learnFuncParams=c(0.2), 
     updateFunc="JE_Order", updateFuncParams=c(0.0),    
-    shufflePatterns=TRUE, linOut=TRUE, inputsTest=NULL, targetsTest=NULL, ...) {
+    shufflePatterns=FALSE, linOut=TRUE, inputsTest=NULL, targetsTest=NULL, ...) {
   
   
   x <- as.matrix(x)
