@@ -24,29 +24,33 @@
 #############################################################################
 
 
-#' This function creates a multilayer perceptron (MLP) and trains it.
-#' MLPs are fully connected feedforward networks, and probably the most 
-#' common network architecture in use.  
-#' Training is usually performed by error backpropagation or a related procedure. 
+#' This function creates a multilayer perceptron (MLP) and trains it. MLPs are
+#' fully connected feedforward networks, and probably the most common network
+#' architecture in use.  Training is usually performed by error backpropagation
+#' or a related procedure.
 #'  
-#' There are a lot of different learning functions present in SNNS that can be 
-#' used together with this function, e.g., \code{Std_Backpropagation}, \code{BackpropBatch},
-#' \code{BackpropChunk}, \code{BackpropMomentum}, \code{BackpropWeightDecay}, \code{Rprop},
-#' \code{Quickprop}, \code{SCG} (scaled conjugate gradient), ...
+#' There are a lot of different learning functions present in SNNS that can be
+#' used together with this function, e.g., \code{Std_Backpropagation},
+#' \code{BackpropBatch}, \code{BackpropChunk}, \code{BackpropMomentum},
+#' \code{BackpropWeightDecay}, \code{Rprop}, \code{Quickprop}, \code{SCG}
+#' (scaled conjugate gradient), ...
 #' 
-#' \code{Std_Backpropagation}, \code{BackpropBatch}, e.g., have two parameters, the learning rate
-#' and the maximum output difference. The learning rate is usually a value between 0.1 and 1.
-#' It specifies the gradient descent step width. The maximum difference defines, how much difference between output
-#' and target value is treated as zero error, and not backpropagated. This parameter is used to prevent overtraining.
-#' For a complete list of the parameters of all the learning functions, see the SNNS User Manual, pp. 67.
+#' \code{Std_Backpropagation}, \code{BackpropBatch}, e.g., have two parameters,
+#' the learning rate and the maximum output difference. The learning rate is
+#' usually a value between 0.1 and 1. It specifies the gradient descent step
+#' width. The maximum difference defines, how much difference between output and
+#' target value is treated as zero error, and not backpropagated. This parameter
+#' is used to prevent overtraining. For a complete list of the parameters of all
+#' the learning functions, see the SNNS User Manual, pp. 67.
 #' 
 #' The defaults that are set for initialization and update functions usually don't have to be changed. 
 #' 
 #' 
 #' 
 #' @title Create and train a multi-layer perceptron (MLP)
-#' @references
-#' Rosenblatt, F. (1958), 'The perceptron: A probabilistic model for information storage and organization in the brain', Psychological Review 65(6), 386--408.
+#' @references Rosenblatt, F. (1958), 'The perceptron: A probabilistic model for
+#' information storage and organization in the brain', Psychological Review
+#' 65(6), 386--408.
 #' 
 #' Rumelhart, D. E.; Clelland, J. L. M. & Group, P. R. (1986), Parallel distributed processing :explorations in the microstructure of cognition, Mit, Cambridge, MA etc.
 #'  
@@ -57,8 +61,7 @@
 #' @export
 mlp <- function(x, ...) UseMethod("mlp")
 
-#' Create and train a multi-layer perceptron (mlp).
-#' 
+
 #' @param x a matrix with training inputs for the network
 #' @param y the corresponding targets values
 #' @param size number of units in the hidden layer(s)
@@ -74,6 +77,9 @@ mlp <- function(x, ...) UseMethod("mlp")
 #' @param linOut sets the activation function of the output units to linear or logistic
 #' @param inputsTest a matrix with inputs to test the network
 #' @param targetsTest the corresponding targets for the test input
+#' @param pruneFunc the pruning function to use
+#' @param pruneFuncParams the parameters for the pruning function. Unlike the other functions, 
+#' these have to be given in a named list. See the pruning demos for further explanation. 
 #' @param ... additional function parameters (currently not used)
 #' @return an \code{\link{rsnns}} object.
 #' @export
@@ -122,45 +128,46 @@ mlp <- function(x, ...) UseMethod("mlp")
 #' #confusion matrix with 402040-method
 #' confusionMatrix(iris$targetsTrain, encodeClassLabels(fitted.values(model),
 #'                                                        method="402040", l=0.4, h=0.6))
-mlp.default <- function(x, y, size=c(5), maxit=100, 
+mlp.default <- function(x, y, size=c(5), maxit=100,  
     initFunc="Randomize_Weights", initFuncParams=c(-0.3, 0.3), 
     learnFunc="Std_Backpropagation", learnFuncParams=c(0.2, 0.0), 
     updateFunc="Topological_Order", updateFuncParams=c(0.0),
     hiddenActFunc="Act_Logistic",
-    shufflePatterns=TRUE, linOut=FALSE, inputsTest=NULL, targetsTest=NULL, ...) {
-  
+    shufflePatterns=TRUE, linOut=FALSE, inputsTest=NULL, targetsTest=NULL, pruneFunc=NULL, pruneFuncParams=NULL, ...) {
+
+
   x <- as.matrix(x)
   y <- as.matrix(y)
-  
-  checkInput(x,y)
 
-  nInputs <- dim(x)[2L]
-  nOutputs <- dim(y)[2L]
-  
-  snns <- rsnnsObjectFactory(subclass=c("mlp"), nInputs=nInputs, maxit=maxit, 
-      initFunc=initFunc, initFuncParams=initFuncParams, 
-      learnFunc=learnFunc, learnFuncParams=learnFuncParams, 
-      updateFunc=updateFunc, 
-      updateFuncParams=updateFuncParams,
-      shufflePatterns=shufflePatterns, computeIterativeError=TRUE)
+  checkInput(x, y)
+
+  nInputs <- ncol(x)
+  nOutputs <- ncol(y)
+
+
+  snns <- rsnnsObjectFactory(
+    subclass=c("mlp"), nInputs=nInputs, maxit=maxit, 
+    initFunc=initFunc, initFuncParams=initFuncParams, 
+    learnFunc=learnFunc, learnFuncParams=learnFuncParams, 
+    updateFunc=updateFunc, updateFuncParams=updateFuncParams,
+    shufflePatterns=shufflePatterns, computeIterativeError=TRUE,
+    pruneFunc=pruneFunc, pruneFuncParams=pruneFuncParams)
   
   snns$archParams <- list(size=size)
-  
   snns$snnsObject$setUnitDefaults(0,0,1,0,1,"Act_Logistic","Out_Identity")
-  snns$snnsObject$createNet(unitsPerLayer=c(nInputs, size, nOutputs), fullyConnectedFeedForward=TRUE)
+  snns$snnsObject$createNet(unitsPerLayer=c(nInputs, size, nOutputs),
+                            fullyConnectedFeedForward=TRUE,
+                            iNames = colnames(x), oNames = colnames(y))
   
-  if(linOut) {
-    outputActFunc <- "Act_Identity"
-  } else {
-    outputActFunc <- "Act_Logistic"
-  }
+  outputActFunc <- if(linOut)  "Act_Identity" else  "Act_Logistic"
   
   snns$snnsObject$setTTypeUnitsActFunc("UNIT_INPUT", "Act_Identity")
   snns$snnsObject$setTTypeUnitsActFunc("UNIT_HIDDEN", hiddenActFunc)
   snns$snnsObject$setTTypeUnitsActFunc("UNIT_OUTPUT", outputActFunc)
   
+  snns <- train(snns,
+                inputsTrain = x, inputsTest = inputsTest,
+                targetsTrain = y, targetsTest = targetsTest)
   
-  snns <- train(snns, inputsTrain=x, targetsTrain=y, inputsTest=inputsTest, targetsTest=targetsTest)
-
 }
 
